@@ -101,11 +101,12 @@ class PhotosLibrary:
             photo_paths: list of file paths to import as str or pathlib.Path
             album: optional, Album object for album to import into
             skip_duplicate_check: if True, Photos will not check for duplicates on import, default is False. 
-            NOTE: If you attempt to import a duplicate photo and skip_duplicate_check != True, 
-            Photos will block with drop-down sheet until the user clicks "Cancel, Import, or Don't Import."
-
+            
         Returns:
             list of Photo objects for impoted photos
+            
+        NOTE: If you attempt to import a duplicate photo and skip_duplicate_check != True, 
+            Photos will block with drop-down sheet until the user clicks "Cancel, Import, or Don't Import."
         """
         # stringify paths in case pathlib.Path paths are passed
         photo_paths = [str(photo_path) for photo_path in photo_paths]
@@ -117,7 +118,9 @@ class PhotosLibrary:
                 skip_duplicate_check,
             )
         else:
-            photo_ids = run_script("_photoslibrary_import", photo_paths, skip_duplicate_check)
+            photo_ids = run_script(
+                "_photoslibrary_import", photo_paths, skip_duplicate_check
+            )
 
         return [Photo(photo) for photo in photo_ids]
 
@@ -580,7 +583,7 @@ class Folder:
         """ parent container id """
         return run_script("_folder_parent", self.id)
 
-    # TODO: if no parent should return a "My Albums" object that contains all top-level folders/albums
+    # TODO: if no parent should return a "My Albums" object that contains all top-level folders/albums?
     @property
     def parent(self):
         """ Return parent Folder object """
@@ -630,22 +633,27 @@ class Folder:
         return None
 
     @property
-    def folders(self):
-        """ list of Folder objects for folders contained in folder """
+    def subfolders(self):
+        """ list of Folder objects for immediate sub-folders contained in folder """
         folder_ids = run_script("_folder_folders", self.id)
         return [Folder(uuid) for uuid in folder_ids]
 
     def folder(self, name):
-        """Return Folder object for subfolder folder named name
-        or None if no matching subfolder
+        """Folder object for first subfolder folder named name.
+
+        Args:
+            name: name of folder to to return
+
+        Returns:
+            Folder object for first subfolder who's name matches name or None if not found
         """
-        for folder in self.folders:
+        for folder in self.subfolders:
             if folder.name == name:
                 return folder
         return None
 
     def create_album(self, name):
-        """creates an album in this folder
+        """Creates an album in this folder
 
         Args:
             name: name of new album
